@@ -1,9 +1,17 @@
+import sys
+
 from pyramid.httpexceptions import HTTPUnauthorized, HTTPNotFound
 from pyramid.security import forget
 from pyramid.response import Response
 from pyramid.view import view_config, forbidden_view_config
 
 
+if sys.version_info[0] < 3:
+    from urllib2 import unquote
+else:
+    from urllib.parse import unquote
+
+
 @forbidden_view_config()
 def basic_challenge(request):
     response = HTTPUnauthorized()
@@ -13,7 +21,8 @@ def basic_challenge(request):
 
 @view_config(route_name='site', permission='view')
 def site(request):
-    s3file = request.s3.get_file(request.path)
+    path = unquote(request.path)
+    s3file = request.s3.get_file(path)
     if s3file is None:
         return HTTPNotFound()
     response = Response(content_type=s3file.content_type)
